void circle(std::ofstream & ffout, fastjet::PseudoJet & p, double radius, unsigned ls, string title)
{
  ffout << "," << radius << "*sin(t)+" << p.eta() << ","
	<< radius << "*cos(t)+" << p.phi_std()
	<< " w l ls " << ls << title <<" \\" <<std::endl;
  return;
}

void cell(std::ofstream & ffout, fastjet::PseudoJet & p)
{
  unsigned ps=0;
  if(p.perp() > 1.) ps=1;
  if(p.perp() > 5.) ps=2;
  if(p.perp() > 10.) ps=3;
  if(p.perp() > 50.) ps=4;
  if(p.perp() > 100.) ps=5;
  ffout << "," << p.eta() << "," <<  p.phi_std()
	<< " w points ps " << ps << " pt 4 linecolor rgb '#778899'  lw 1 notitle\\" <<endl;
  return;
}


void set_header_for_display(std::ofstream & ffout, const double xIn, const double yIn, const double rIn, string label)
{
  double xMin = xIn - rIn;
  double xMax = xIn + rIn;
  double yMin = yIn - rIn;
  double yMax = yIn + rIn;
  ffout << "set terminal postscript eps size 3.5,2.62 enhanced color font 'Helvetica,14' linewidth 1" << std::endl;
  ffout << "set output 'event_view.eps'" << std::endl;

  ffout << "unset label" << std::endl; 
  ffout << "unset arrow" << std::endl;      
  ffout << "set key outside" << std::endl;
  ffout << "set xrange ["<<xMin<<":"<<xMax<<"]" << std::endl;
  ffout << "set yrange ["<<yMin<<":"<<yMax<<"]" << std::endl;
  ffout << "set label 1 at graph  -0.18, 0.5 '{/Symbol f} ' " <<std::endl;
  ffout << "set label 2 at graph  0.5,  -0.1 '{/Symbol h} ' " <<std::endl;
  ffout << "set label 3 at graph 0.15, 1.05 '"<< label <<"'" <<std::endl;


  ffout << "set size ratio -1" << std::endl;
  ffout << "set parametric" << std::endl;
  ffout << "set style line 1 lt 1 lw 2" << std::endl; 
  ffout << "set style line 2 lt 2 lw 2 linecolor rgb '#DC143C' " << std::endl;
  ffout << "set style line 3 lt 3 lw 2" << std::endl;
  ffout << "set style line 4 lt 4 lw 2" << std::endl; 
  ffout << "set style line 5 lt 5 lw 2" << std::endl;
  ffout << "set style line 6 lt 1 lw 2 lc rgbcolor 'black' " << std::endl;
  ffout << "plot 0.4*sin(t)+ 6, 0.4*cos(t)+4 w l ls 1 notitle\\" <<std::endl;
  return;
}
void set_header_for_display2(std::ofstream & ffout, const double xIn, const double yIn, const double rIn, string label)
{
  double xMin = xIn - rIn;
  double xMax = xIn + rIn;
  double yMin = yIn - rIn;
  double yMax = yIn + rIn;
  ffout << "set terminal postscript eps size 3.5,2.62 enhanced color font 'Helvetica,14' linewidth 1" << std::endl;
  ffout << "set output 'event_view2.eps'" << std::endl;

  ffout << "unset label" << std::endl; 
  ffout << "unset arrow" << std::endl;      
  ffout << "set key outside" << std::endl;
  ffout << "set xrange ["<<xMin<<":"<<xMax<<"]" << std::endl;
  ffout << "set yrange ["<<yMin<<":"<<yMax<<"]" << std::endl;
  ffout << "set label 1 at graph  -0.18, 0.5 '{/Symbol f} ' " <<std::endl;
  ffout << "set label 2 at graph  0.5,  -0.1 '{/Symbol h} ' " <<std::endl;
  ffout << "set label 3 at graph 0.15, 1.05 '"<< label <<"'" <<std::endl;


  ffout << "set size ratio -1" << std::endl;
  ffout << "set parametric" << std::endl;
  ffout << "set style line 1 lt 1 lw 2" << std::endl; 
  ffout << "set style line 2 lt 2 lw 2 linecolor rgb '#DC143C' " << std::endl;
  ffout << "set style line 3 lt 3 lw 2" << std::endl;
  ffout << "set style line 4 lt 4 lw 2" << std::endl; 
  ffout << "set style line 5 lt 5 lw 2" << std::endl;
  ffout << "set style line 6 lt 1 lw 2 lc rgbcolor 'black' " << std::endl;
  ffout << "plot 0.4*sin(t)+ 6, 0.4*cos(t)+4 w l ls 1 notitle\\" <<std::endl;
  return;
}

void output_hadron_to_display(std::ofstream & ffout, std::vector< fastjet::PseudoJet> & hadrons)
{
  for (unsigned idummy=0;idummy<hadrons.size();idummy++){
    cell(ffout, hadrons.at(idummy));
  }  
  return;
}

void output_parton_to_display(std::ofstream & ffout, std::vector< fastjet::PseudoJet> & partons)
{
  for(unsigned idummy=0;idummy<partons.size();idummy++)
    {
      //double rad = 0.05*max();
      double rad = 0.05;
      ffout << "," << rad << "*sin(t)+" 
	    << partons.at(idummy).eta() << ","
	    << rad << "*cos(t)+" 
	    << partons.at(idummy).phi()
	    << " w l ls 1 notitle\\" <<std::endl;
    }
}

void set_footer_for_display(std::ofstream & ffout)
{
 // ffout << ", \"sample_event_out.dat\" using 1:2 w points title \"cell\" \\" <<std::endl;
  ffout << ", \"sample_event_parton.dat\" index 0 using 1:2 w points pt 7 ps 2 linecolor rgb '#FF4500'  title \"b-quarks\" \\" <<std::endl;
  //ffout << ", \"sample_event_parton.dat\" index 1 using 1:2 w points pt 5 title \"W\" \\" <<std::endl;
  ffout << ", 0.4*sin(t)+ 6, 0.4*cos(t)+4 w l ls 1 notitle" <<std::endl;
  return;
}
void set_footer_for_display2(std::ofstream & ffout)
{
 // ffout << ", \"sample_event_out.dat\" using 1:2 w points title \"cell\" \\" <<std::endl;
  ffout << ", \"sample_event_parton2.dat\" index 0 using 1:2 w points pt 7 ps 2 linecolor rgb '#FF4500'  title \"b-quarks\" \\" <<std::endl;
  //ffout << ", \"sample_event_parton.dat\" index 1 using 1:2 w points pt 5 title \"W\" \\" <<std::endl;
  ffout << ", 0.4*sin(t)+ 6, 0.4*cos(t)+4 w l ls 1 notitle" <<std::endl;
  return;
}
void output_vec_pseudojet(  std::ofstream & fout, std::vector<fastjet::PseudoJet> & vec_jets)
{
  for(unsigned idum=0;idum<vec_jets.size();idum++){    
    fout << vec_jets.at(idum).eta() << " ";
    fout << vec_jets.at(idum).phi_std() << " ";
    fout << vec_jets.at(idum).perp() << " " ;
    fout << vec_jets.at(idum).user_index() <<std::endl;
  }
  return;
}
